CREATE DATABASE storelocator
GO

USE storelocator
GO

CREATE TABLE [STORE_TABLE] (
	[ID] 			[int] IDENTITY (1, 1) NOT NULL,
	[CATEGORIES]	[varchar] (200) NULL,
	[ZIPCODE] 		[varchar] (7) NOT NULL,
	[NAME] 			[varchar] (100) NOT NULL,
	[ADDRESS1] 		[varchar] (255) NULL,
	[ADDRESS2] 		[varchar] (255) NULL,
	[CITY] 			[varchar] (100) NULL,
	[STATE] 		[varchar] (100) NULL,
	[COUNTRY] 		[varchar] (100) NULL,
	[TELNO] 		[varchar] (15) NULL,
	[FAXNO] 		[varchar] (15) NULL,
	[EMAIL] 		[varchar] (100) NULL,
	[WEBSITE] 		[varchar] (255) NULL,
	[CUSTOM1] 		[varchar] (255) NULL,
	[CUSTOM2] 		[varchar] (255) NULL,
	[CUSTOM3] 		[varchar] (255) NULL,
	[CUSTOM4] 		[varchar] (255) NULL,
	[CUSTOM5] 		[varchar] (255) NULL,
	[HIDDEN] 		[int] NOT NULL DEFAULT 0,
	[PREFERRED] 		[int] NOT NULL DEFAULT 0,
	[USERID] 		[int] NOT NULL DEFAULT 1,
	PRIMARY KEY (ID)
)
GO

CREATE INDEX STORE_ID
ON STORE_TABLE (ID)
GO

CREATE INDEX STORE_CATEGORIES
ON STORE_TABLE (CATEGORIES)
GO

CREATE INDEX STORE_ZIPCODE
ON STORE_TABLE (ZIPCODE)
GO

CREATE INDEX STORE_CITY
ON STORE_TABLE (CITY)
GO

CREATE INDEX STORE_STATE
ON STORE_TABLE (STATE)
GO

CREATE INDEX STORE_HIDDEN
ON STORE_TABLE (HIDDEN)
GO

CREATE INDEX STORE_PREFERRED
ON STORE_TABLE (PREFERRED)
GO

CREATE INDEX STORE_USERID
ON STORE_TABLE (USERID)
GO

CREATE TABLE [USER_TABLE] (
	[USERID] 		[int] IDENTITY (1, 1) NOT NULL,
	[USERNAME] 		[varchar] (50) NOT NULL,
	[USERPASSWORD] 		[varchar] (50) NOT NULL,
	[ISACTIVE] 		[int] NOT NULL DEFAULT 1,
	PRIMARY KEY (USERID)
)
GO

CREATE INDEX USER_USERID
ON USER_TABLE (USERID)
GO

CREATE INDEX USER_ISACTIVE
ON USER_TABLE (ISACTIVE)
GO


CREATE TABLE [CONFIGURATION_TABLE] (
	[EMAIL]			[varchar] (50) NULL,
	[NAME]			[varchar] (50) NULL,
	[WEBSITETITLE] 		[varchar] (50) NULL,
	[HEADINGTEXT] 		[varchar] (50) NULL,
	[DEFAULTRADIUS] 	[int] NOT NULL,
	[SYSTEMDEFINERADIUS] 	[int] NOT NULL,
	[DEFAULTMAXRECORD] 	[int] NOT NULL,
	[SYSTEMDEFINEMAXRECORD]	[int] NOT NULL,
	[MEASUREMENT] 		[varchar] (10) NULL,
	[STOREHEADER] 		[varchar] (50) NULL,
	[DISTANCEHEADER] 	[varchar] (50) NULL,
	[ENABLEZIPCODE] 	[int] NOT NULL DEFAULT 1,
	[ENABLENAME] 		[int] NOT NULL DEFAULT 1,
	[ENABLEADDRESS1] 	[int] NOT NULL DEFAULT 1,
	[ENABLEADDRESS2] 	[int] NOT NULL DEFAULT 1,
	[ENABLECITY] 		[int] NOT NULL DEFAULT 1,
	[ENABLESTATE] 		[int] NOT NULL DEFAULT 1,
	[ENABLECOUNTRY] 	[int] NOT NULL DEFAULT 1,
	[ENABLETELNO] 		[int] NOT NULL DEFAULT 1,
	[ENABLEFAXNO] 		[int] NOT NULL DEFAULT 1,
	[ENABLEEMAIL] 		[int] NOT NULL DEFAULT 1,
	[ENABLEWEBSITE] 	[int] NOT NULL DEFAULT 1,
	[ENABLECUSTOM1] 	[varchar] (50) NULL,
	[ENABLECUSTOM2] 	[varchar] (50) NULL,
	[ENABLECUSTOM3] 	[varchar] (50) NULL,
	[ENABLECUSTOM4] 	[varchar] (50) NULL,
	[ENABLECUSTOM5] 	[varchar] (50) NULL,
	[ENABLECATEGORIES]	[int] NOT NULL DEFAULT 1,
	[MAPQUEST] 		[varchar] (50) NULL,
	[YAHOOMAP] 		[varchar] (50) NULL,
	[GOOGLEMAP] 		[varchar] (50) NULL,
	[SHOWMAP] 		[int] NOT NULL DEFAULT 1,
	[NEWPAGE] 		[int] NOT NULL DEFAULT 1,
	[MAPTEXT] 		[varchar] (50) NULL,
	[ACTIVE] 		[int] NULL,
	[ADMINMAXRECORD] 	[int] NOT NULL,
	[FRONTENDMAXRECORD] 	[int] NOT NULL,
	[ODDCOLOR] 		[varchar] (50) NOT NULL DEFAULT '#FFFFEE',
	[EVENCOLOR] 		[varchar] (50) NOT NULL DEFAULT '#FFFFFF',
	[HEADERCOLOR] 		[varchar] (50) NOT NULL DEFAULT '#FFFFFF',
	[LOGOLINK] 		[varchar] (100) NULL,
	[CUSTOMDISTANCE] 	[varchar] (200) NULL,
	[CUSTOMMAXRECORD] 	[varchar] (200) NULL,
	[CUSTOMZIPCODE] 	[varchar] (200) NULL,
	[CUSTOMGO] 		[varchar] (200) NULL,
	[CUSTOMADVANCESEARCH] 	[varchar] (200) NULL,
	[CUSTOMBASICSEARCH] 	[varchar] (200) NULL,
	[CUSTOMCITY] 		[varchar] (200) NULL,
	[CUSTOMSTATE] 		[varchar] (200) NULL,
	[CUSTOMMILES] 		[varchar] (200) NULL,
	[CUSTOMKILOMETERS] 	[varchar] (200) NULL,
	[CUSTOMSORTBY] 		[varchar] (200) NULL,
	[CUSTOMSORTDISTANCE] 	[varchar] (200) NULL,
	[CUSTOMSORTNAME] 	[varchar] (200) NULL,
	[CUSTOMSORTADDRESS] 	[varchar] (200) NULL,
	[CUSTOMSORTCITY] 	[varchar] (200) NULL,
	[CUSTOMSORTSTATE] 	[varchar] (200) NULL,
	[CUSTOMSORTCOUNTRY] 	[varchar] (200) NULL,
	[CUSTOMDISTANCERANGE] 	[varchar] (200) NULL,
	[CUSTOMMAXRECORDRANGE] 	[varchar] (200) NULL,
	[CUSTOMTELNO] 		[varchar] (200) NULL,
	[CUSTOMFAXNO] 		[varchar] (200) NULL,
	[CUSTOMWEBSITE] 	[varchar] (200) NULL,
	[CUSTOMEMAIL] 		[varchar] (200) NULL,
	[CUSTOMCATEGORIES]	[varchar] (200) NULL,
	[MSGZIPCODEEMPTY]	[varchar] (200) NULL,
	[MSGRESULTEMPTY]	[varchar] (200) NULL,
	[MSGMISSINGPARAM]	[varchar] (200) NULL,
	[USERID] 		[int] NOT NULL DEFAULT 1
)
GO

CREATE INDEX CONFIGURATION_USERID
ON CONFIGURATION_TABLE (USERID)
GO


CREATE TABLE [COUNTRY_TABLE] (
	[COUNTRY_CODE] 		[varchar] (2) NOT NULL,
	[COUNTRY_NAME] 		[varchar] (100) NOT NULL,
	PRIMARY KEY (COUNTRY_CODE)
)
GO

CREATE INDEX COUNTRY_COUNTRYCODE
ON COUNTRY_TABLE (COUNTRY_CODE)
GO


INSERT INTO USER_TABLE (USERNAME, USERPASSWORD, ISACTIVE)
VALUES ('admin', '12345', 1)
GO

INSERT INTO CONFIGURATION_TABLE (EMAIL, NAME, WEBSITETITLE, HEADINGTEXT, DEFAULTRADIUS, SYSTEMDEFINERADIUS, DEFAULTMAXRECORD, SYSTEMDEFINEMAXRECORD, 
                      MEASUREMENT, STOREHEADER, DISTANCEHEADER, ENABLEZIPCODE, ENABLENAME, ENABLEADDRESS1, ENABLEADDRESS2, ENABLECITY, ENABLESTATE, 
                      ENABLECOUNTRY, ENABLETELNO, ENABLEFAXNO, ENABLEEMAIL, ENABLEWEBSITE, ENABLECUSTOM1, ENABLECUSTOM2, ENABLECUSTOM3, ENABLECUSTOM4, 
                      ENABLECUSTOM5, ENABLECATEGORIES, MAPQUEST, YAHOOMAP, GOOGLEMAP, SHOWMAP, NEWPAGE, MAPTEXT, ACTIVE, ADMINMAXRECORD, FRONTENDMAXRECORD, 
                      ODDCOLOR, EVENCOLOR, HEADERCOLOR, LOGOLINK, CUSTOMDISTANCE, CUSTOMMAXRECORD, CUSTOMZIPCODE, CUSTOMGO, CUSTOMADVANCESEARCH,
                      CUSTOMBASICSEARCH, CUSTOMCITY, CUSTOMSTATE, CUSTOMMILES, CUSTOMKILOMETERS, CUSTOMSORTBY, CUSTOMSORTDISTANCE,
                      CUSTOMSORTNAME, CUSTOMSORTADDRESS, CUSTOMSORTCITY, CUSTOMSORTSTATE, CUSTOMSORTCOUNTRY, CUSTOMDISTANCERANGE, CUSTOMMAXRECORDRANGE,
                      CUSTOMTELNO, CUSTOMFAXNO, CUSTOMWEBSITE, CUSTOMEMAIL, CUSTOMCATEGORIES, MSGZIPCODEEMPTY, MSGRESULTEMPTY, MSGMISSINGPARAM, USERID)
VALUES ('sales@zipcodeworld.com', 'ZIPCodeWorld', 'www.zipcodeworld.com', 'ZIPCodeWorld', 50, 0, 50, 0, 'miles', 'Store', 'Header', 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
			1, '', '', '', '', '', 0, 'www.mapquest.com/maps/map.adp', 'maps.yahoo.com/maps_result', 'map.google.com/', 1, 1, 'Show Map', 1, 50, 50, '#FFFFEE', 
			'#FFFFFF', '#FFFFFF','','Search within','Number record display','ZIP Code','Go','Advance Search','Basic Search','City','State','Miles','Kilometers',
			'Sort By','Distance','Name','Address','City','State','Country','5,10,25,50,100,250','5,10,25,50,100,250','Tel No.','Fax No.','WEB SITE','Email', 'Limit search to',
			'Status: ZIP code cannot be empty.','Status: No store or dealer found.','Status: Please fill in at least one search option.',1)
GO

BULK INSERT COUNTRY_TABLE
FROM '<Your Web Directory>\Database\country.txt' 
WITH 
( 
	FIELDTERMINATOR = '\t', 
        ROWTERMINATOR = '\n' 
)
GO

CREATE DATABASE zipcodeworld
GO 
USE zipcodeworld
GO
CREATE TABLE [ZIPCODEWORLDPREMIUM] (
	[ZIP_CODE] [varchar] (50) NOT NULL,
	[LATITUDE] [varchar] (50) NULL,
	[LONGITUDE] [varchar] (50) NULL,
	PRIMARY KEY (ZIP_CODE)
)
GO

CREATE INDEX ZIPCODEWORLD_ZIPCODE
ON ZIPCODEWORLDPREMIUM (ZIP_CODE)
GO

BULK INSERT ZIPCODEWORLDPREMIUM
FROM '<Your Web Directory>\Database\ZIPCODEWORLD-STORELOCATOR-US.CSV' 
WITH 
( 
	FIELDTERMINATOR = ',', 
        ROWTERMINATOR = '\n' 
)
GO